@@ -1,8 +1,13 @@
 import pickle
 
+from calendar import timegm
+from datetime import datetime
 from functools import wraps
-from typing import Callable, Iterable
+from typing import Callable
+from typing import Dict
 from typing import Generic
+from typing import Iterable
+from typing import List
 from typing import Optional
 from typing import TypeVar
 
@@ -51,10 +56,10 @@ def pickleable(obj) -> Optional[bytes]:
 def synchronized(lock):
     def wrap(f):
         @wraps(f)
-        def newFunction(*args, **kw):
+        def lockedFunction(*args, **kw):
             with lock:
                 return f(*args, **kw)
-        return newFunction
+        return lockedFunction
     return wrap
 
 
@@ -64,3 +69,21 @@ def first(iterable: Iterable):
 
 def last(iterable: Iterable):
     return iterable[-1]
+
+
+def key_for(value: T, dct: Dict) -> Optional[T]:
+    try:
+        return list(dct.keys())[list(dct.values()).index(value)]
+    except ValueError:
+        return None
+
+
+def swap(lst: List, idx1: int, idx2: int) -> List:
+    lst[idx1], lst[idx2] = lst[idx2], lst[idx1]
+    return lst
+
+
+def microsecond_timestamp(clock: Callable[[], datetime] = datetime.utcnow) -> int:
+    now = clock()
+    return  int(timegm(now.timetuple()) * 1e6 + now.microsecond)
+
